#include <iostream>
#include <stdexcept>
#include <memory>

class SubComponent {
public:
    SubComponent(int id) {
        if (id < 0) throw std::invalid_argument("Invalid ID");
        std::cout << "SubComponent " << id << " created" << std::endl;
    }
    ~SubComponent() { std::cout << "SubComponent destroyed" << std::endl; }
};

class MainComponent {
private:
    std::unique_ptr<SubComponent> sub1;
    std::unique_ptr<SubComponent> sub2;

public:
    MainComponent(int id1, int id2) 
        : sub1(std::make_unique<SubComponent>(id1)),
          sub2(std::make_unique<SubComponent>(id2)) {
        std::cout << "MainComponent created" << std::endl;
    }

    ~MainComponent() { std::cout << "MainComponent destroyed" << std::endl; }
};

int main() {
    try {
        MainComponent comp(1, -2);
    } catch (const std::exception& e) {
        std::cerr << "Exception caught: " << e.what() << std::endl;
    }
    return 0;
}
